@@ -1,4 +1,4 @@
-use postscript::compact::Operator;
+use postscript::compact::operation::Operator;
 use random::{self, Source};
 use test::{Bencher, black_box};
 
@@ -36,22 +36,7 @@ fn operator_get(bencher: &mut Bencher) {
     let codes = generate_codes(&mut source, SAMPLES);
     bencher.iter(|| {
         for &code in &codes {
-            black_box(Operator::from(code).unwrap());
-        }
-    });
-}
-
-#[bench]
-fn string_index_get(bencher: &mut Bencher) {
-    use postscript::compact::{StringID, Strings};
-
-    let mut source = random::default().seed([69, 42]);
-    let sids = source.iter::<u64>().take(SAMPLES).map(|number| (number as StringID) % 391)
-                                                 .collect::<Vec<_>>();
-    let index = Strings::default();
-    bencher.iter(|| {
-        for &sid in &sids {
-            black_box(index.get(sid));
+            black_box(ok!(Operator::from(code)));
         }
     });
 }
@@ -83,5 +68,5 @@ fn generate_codes<T: Source>(source: &mut T, count: usize) -> Vec<u16> {
 }
 
 fn generate_operators<T: Source>(source: &mut T, count: usize) -> Vec<Operator> {
-    generate_codes(source, count).iter().map(|&code| Operator::from(code).unwrap()).collect()
+    generate_codes(source, count).iter().map(|&code| ok!(Operator::from(code))).collect()
 }
